@@ -218,8 +218,6 @@ typedef union
 static void plugin_data_new (ITNPPluginData** data);
 // Retrieve the current document's documentbase.
 static gchar* plugin_get_documentbase (NPP instance);
-// Notify the user that the appletviewer is not installed correctly.
-static void plugin_display_failure_dialog ();
 // Callback used to monitor input pipe status.
 static gboolean plugin_in_pipe_callback (GIOChannel* source,
                                          GIOCondition condition,
@@ -243,6 +241,8 @@ static void appletviewer_monitor(GPid pid, gint status, gpointer data);
 void plugin_send_initialization_message(char* instance, gulong handle,
                                                int width, int height,
                                                char* url);
+/* Returns JVM options set in itw-settings */
+static std::vector<std::string*>* get_jvm_args();
 
 // Global instance counter.
 // Mutex to protect plugin_instance_counter.
@@ -1127,30 +1127,6 @@ plugin_get_documentbase (NPP instance)
 }
 #endif
 
-// This function displays an error message if the appletviewer has not
-// been installed correctly.
-static void
-plugin_display_failure_dialog ()
-{
-  GtkWidget* dialog = NULL;
-
-  PLUGIN_DEBUG ("plugin_display_failure_dialog\n");
-
-  dialog = gtk_message_dialog_new (NULL,
-                                   GTK_DIALOG_DESTROY_WITH_PARENT,
-                                   GTK_MESSAGE_ERROR,
-                                   GTK_BUTTONS_CLOSE,
-                                   FAILURE_MESSAGE,
-                                   appletviewer_executable);
-  gtk_widget_show_all (dialog);
-  gtk_dialog_run (GTK_DIALOG (dialog));
-  gtk_widget_destroy (dialog);
-
-  PLUGIN_DEBUG ("plugin_display_failure_dialog return\n");
-}
-
-
-
 // plugin_in_pipe_callback is called when data is available on the
 // input pipe, or when the appletviewer crashes or is killed.  It may
 // be called after data has been destroyed in which case it simply
@@ -1617,48 +1593,48 @@ plugin_start_appletviewer (ITNPPluginData* data)
   PLUGIN_DEBUG ("plugin_start_appletviewer\n");
   NPError error = NPERR_NO_ERROR;
 
-  gchar** command_line;
-  gchar** environment;
+  std::vector<std::string> command_line;
+  gchar** environment = NULL;
+  std::vector<std::string*>* jvm_args = get_jvm_args();
 
-  int cmd_num = 0;
-  if (plugin_debug)
+  // Construct command line parameters
+
+  command_line.push_back(appletviewer_executable);
+
+  //Add JVM args to command_line
+  for (int i = 0; i < jvm_args->size(); i++)
   {
-      command_line = (gchar**) malloc(sizeof(gchar*)*11);
-      command_line[cmd_num++] = g_strdup(appletviewer_executable);
-      command_line[cmd_num++] = g_strdup(PLUGIN_BOOTCLASSPATH);
-      // set the classpath to avoid using the default (cwd).
-      command_line[cmd_num++] = g_strdup("-classpath");
-      command_line[cmd_num++] = g_strdup_printf("%s/lib/rt.jar", ICEDTEA_WEB_JRE);
-      command_line[cmd_num++] = g_strdup("-Xdebug");
-      command_line[cmd_num++] = g_strdup("-Xnoagent");
-      if (plugin_debug_suspend)
-      {
-          command_line[cmd_num++] = g_strdup("-Xrunjdwp:transport=dt_socket,address=8787,server=y,suspend=y");
-      } else
-      {
-          command_line[cmd_num++] = g_strdup("-Xrunjdwp:transport=dt_socket,address=8787,server=y,suspend=n");
-      }
-      command_line[cmd_num++] = g_strdup("sun.applet.PluginMain");
-      command_line[cmd_num++] = g_strdup(out_pipe_name);
-      command_line[cmd_num++] = g_strdup(in_pipe_name);
-      command_line[cmd_num] = NULL;
-  } else
-  {
-      command_line = (gchar**) malloc(sizeof(gchar*)*8);
-      command_line[cmd_num++] = g_strdup(appletviewer_executable);
-      command_line[cmd_num++] = g_strdup(PLUGIN_BOOTCLASSPATH);
-      command_line[cmd_num++] = g_strdup("-classpath");
-      command_line[cmd_num++] = g_strdup_printf("%s/lib/rt.jar", ICEDTEA_WEB_JRE);
-      command_line[cmd_num++] = g_strdup("sun.applet.PluginMain");
-      command_line[cmd_num++] = g_strdup(out_pipe_name);
-      command_line[cmd_num++] = g_strdup(in_pipe_name);
-      command_line[cmd_num] = NULL;
+    command_line.push_back(*jvm_args->at(i));
   }
 
-  environment = plugin_filter_environment();
+  command_line.push_back(PLUGIN_BOOTCLASSPATH);
+  // set the classpath to avoid using the default (cwd).
+  command_line.push_back("-classpath");
+  command_line.push_back(ICEDTEA_WEB_JRE "/lib/rt.jar");
 
-  if (!g_spawn_async (NULL, command_line, environment,
-		      (GSpawnFlags) G_SPAWN_DO_NOT_REAP_CHILD,
+  if (plugin_debug)
+  {
+    command_line.push_back("-Xdebug");
+    command_line.push_back("-Xnoagent");
+
+    //Debug flags
+    std::string debug_flags = "-Xrunjdwp:transport=dt_socket,address=8787,server=y,";
+    debug_flags += plugin_debug_suspend ? "suspend=y" : "suspend=n";
+    command_line.push_back(debug_flags);
+  }
+
+  command_line.push_back("sun.applet.PluginMain");
+  command_line.push_back(out_pipe_name);
+  command_line.push_back(in_pipe_name);
+
+  // Finished command line parameters
+
+  environment = plugin_filter_environment();
+  std::vector<gchar*> vector_gchar = IcedTeaPluginUtilities::vectorStringToVectorGchar(&command_line);
+  gchar **command_line_args = &vector_gchar[0];
+
+  if (!g_spawn_async (NULL, command_line_args, environment,
+                     (GSpawnFlags) G_SPAWN_DO_NOT_REAP_CHILD,
                       NULL, NULL, &appletviewer_pid, &channel_error))
     {
       if (channel_error)
@@ -1673,15 +1649,11 @@ plugin_start_appletviewer (ITNPPluginData* data)
       error = NPERR_GENERIC_ERROR;
     }
 
-  g_strfreev (environment);
-
-  for (int i = 0; i < cmd_num; i++) {
-    g_free (command_line[i]);
-    command_line[i] = NULL;
-  }
-
-  g_free(command_line);
-  command_line = NULL;
+  //Free memory
+  g_strfreev(environment);
+  IcedTeaPluginUtilities::freeStringPtrVector(jvm_args);
+  jvm_args = NULL;
+  command_line_args = NULL;
 
   if (appletviewer_pid)
     {
@@ -1694,6 +1666,52 @@ plugin_start_appletviewer (ITNPPluginData* data)
   return error;
 }
 
+/*
+ * Returns JVM options set in itw-settings
+ */
+static std::vector<std::string*>*
+get_jvm_args()
+{
+  std::vector < std::string> commands;
+  gchar *output = NULL;
+  std::vector<std::string*>* tokenOutput = NULL;
+
+  commands.push_back(appletviewer_executable);
+  commands.push_back(PLUGIN_BOOTCLASSPATH);
+  commands.push_back("-classpath");
+  commands.push_back(ICEDTEA_WEB_JRE "/lib/rt.jar");
+  commands.push_back("net.sourceforge.jnlp.controlpanel.CommandLine");
+  commands.push_back("get");
+  commands.push_back("deployment.plugin.jvm.arguments");
+
+  std::vector<gchar*> vector_gchar = IcedTeaPluginUtilities::vectorStringToVectorGchar(&commands);
+  gchar **command_line_args = &vector_gchar[0];
+
+  if (!g_spawn_sync(NULL, command_line_args, NULL,
+      (GSpawnFlags) G_SPAWN_STDERR_TO_DEV_NULL, NULL, NULL, &output, NULL, NULL,
+      &channel_error))
+  {
+    PLUGIN_ERROR("Failed to get JVM arguments set for plugin.");
+    output = NULL;
+  }
+
+  tokenOutput = IcedTeaPluginUtilities::strSplit(output, " \n");
+
+  if (!tokenOutput->empty() && *tokenOutput->at(0) =="null")
+  {
+    delete tokenOutput->at(0);
+    tokenOutput->erase(tokenOutput->begin());
+  }
+
+  //Free memory
+  g_free(output);
+  output = NULL;
+  command_line_args = NULL;
+
+  return tokenOutput;
+}
+
+
 /*
  * Replaces certain characters (\r, \n, etc) with HTML escape equivalents.
  *
@@ -2297,7 +2315,7 @@ NP_Initialize (NPNetscapeFuncs* browserTable, NPPluginFuncs* pluginTable)
   np_error = plugin_test_appletviewer ();
   if (np_error != NPERR_NO_ERROR)
     {
-      plugin_display_failure_dialog ();
+      fprintf(stderr, "Unable to find java executable %s\n", appletviewer_executable);
       goto cleanup_appletviewer_executable;
     }
   g_free (filename);
